@@ -1,7 +1,6 @@
 /*
- * gail-gnome-debug.h:
- *
- * Copyright 2002 Sun Microsystems Inc.
+ * LIBGAIL-GNOME -  Accessibility Toolkit Implementation for Bonobo
+ * Copyright 2001 Sun Microsystems Inc.
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Library General Public
@@ -26,7 +25,7 @@
 
 G_BEGIN_DECLS
 
-#ifdef G_ENABLE_DEBUG
+#ifdef GAIL_GNOME_DEBUG
 
 #include <stdio.h>
 
